@@ -27,8 +27,22 @@ sub apply_sql_snippets {
         if ( exists $update_path->{$this_checksum} );
 
     unless ($update) {
+        foreach my $update_entry (values %{$update_path}) {
+            my $post_checksum_index = 0;
+            while (@{$update_entry} > $post_checksum_index) {
+                if ($update_entry->[$post_checksum_index] eq 'SAME_CHECKSUM') {
+                    $post_checksum_index++;
+                    next;
+                }
+                if ($update_entry->[$post_checksum_index+1] eq $this_checksum) {
+                    say "db checksum $this_checksum matching ".$update_entry->[$post_checksum_index]->relative;
+                    return;
+                }
+                $post_checksum_index += 2;
+            }
+        }
         say "No update found that's based on $this_checksum.";
-        exit;
+        return;
     }
 
     if ( $update->[0] eq 'SAME_CHECKSUM' ) {
@@ -84,7 +98,7 @@ sub apply_file {
                 $dbh->rollback;
                 say "SQL error: $_";
                 say "ABORTING!";
-                exit 1;
+                return;
             };
             say "Successful!" if $self->verbose;
         }
@@ -102,7 +116,13 @@ sub apply_file {
         if ( $post_checksum eq $expected_post_checksum ) {
             say "post checksum OK";
             $dbh->commit;
-            return $self->apply_sql_snippets($post_checksum);
+            if ($self->_update_path->{$post_checksum}) {
+                return $self->apply_sql_snippets($post_checksum);
+            }
+            else {
+                say 'No more changes';
+                return;
+            }
         }
         else {
             say "post checksum mismatch!";
@@ -110,7 +130,7 @@ sub apply_file {
             say "  got      $post_checksum";
             $dbh->rollback;
             say "ABORTING!";
-            exit 1;
+            return;
         }
     }
     elsif ($answer eq 's') {
@@ -118,7 +138,7 @@ sub apply_file {
     }
     else {
         say "Not applying $filename, so we stop.";
-        exit;
+        return;
     }
 }
 
@@ -135,7 +155,7 @@ DBIx::SchemaChecksum::App::ApplyChanges - DBIx::SchemaChecksum command apply_cha
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 METHODS
 
